@@ -8,7 +8,7 @@ from MSApi.mixin.GenListMixin import GenerateListMixin
 
 class Assortment(ObjectMS,
                  GenerateListMixin):
-    __type_name = 'assortment'
+    _type_name = 'assortment'
 
     @classmethod
     @caching
