@@ -13,6 +13,3 @@ class Bundle(Assortment,
              ProductfolderMixin):
 
     _type_name = 'bundle'
-
-    def __init__(self, json):
-        super().__init__(json)
