@@ -15,6 +15,3 @@ class Service(Assortment,
               GenerateListMixin):
 
     _type_name = 'service'
-
-    def __init__(self, json):
-        super().__init__(json)
\ No newline at end of file
